@@ -20,7 +20,7 @@
  */
 
 #ifndef __SPUI__
-#define __SPUI__ 
+#define __SPUI__ 0
 
 #include <gnome.h>
 
@@ -28,6 +28,4 @@
 
 gboolean 	spui_load_speech_settings			(GtkWidget *parent_window);
 gboolean	spui_speech_setting_value_add_to_widgets	(Speech *speech_setting);
-void		spui_engine_voice_list_set 			(GList *voice_list);
-void		spui_modify_speaker_values 			(SpeakerSettings *value);
 #endif
