@@ -44,10 +44,19 @@
 #define DEFAULT_BRLMON_PORT			7000
 #define DEFAULT_REMOTE_PORT			7096
 /*____________________________< BRAILLE_DEFAULTS>___________________________*/
+#define MIN_SERIAL_PORT_NO			1
+#define MAX_SERIAL_PORT_NO			4
+
+#define MIN_TTY_CONSOL_NO			1
+#define MAX_TTY_CONSOL_NO			10
+
+#define MIN_BRAILLE_PORT 			1
+#define MAX_BRAILLE_PORT 			10
+
 #define DEFAULT_BRAILLE_ATTRIBUTES		8
-#define DEFAULT_BRAILLE_STYLE 			8
-#define DEFAULT_BRAILLE_CURSOR			2
-#define DEFAULT_BRAILLE_TRANSLATION 		"GE.A2B"
+#define DEFAULT_BRAILLE_STYLE 			"8"
+#define DEFAULT_BRAILLE_CURSOR_STYLE		"underline"
+#define DEFAULT_BRAILLE_TRANSLATION 		"de"
 #define DEFAULT_BRAILLE_DEVICE 			"VARIO20"
 #define DEFAULT_BRAILLE_DEVICE_INDEX 		0
 #define DEFAULT_BRAILLE_DEVICE_COUNT		0
@@ -57,6 +66,18 @@
 #define DEFAULT_BRAILLE_OPTICAL_SENSOR 		0
 #define DEFAULT_BRAILLE_POSITION_SENSOR		2
 /*____________________________< /BRAILLE_DEFAULTS>___________________________*/
+/*____________________________< BRAILLE_MONITOR_DEFAULTS>___________________________*/
+#define DEFAULT_BRAILLE_MONITOR_PANEL_POSITION   	"TOP"
+#define DEFAULT_BRAILLE_MONITOR_MODE			"normal"
+#define DEFAULT_BRAILLE_MONITOR_DOT78_COLOR		"#000000007D00"
+#define DEFAULT_BRAILLE_MONITOR_DOT7_COLOR		"#7D0000000000"
+#define DEFAULT_BRAILLE_MONITOR_DOT8_COLOR		"#00007D000000"
+#define DEFAULT_BRAILLE_MONITOR_LINE			2
+#define DEFAULT_BRAILLE_MONITOR_COLUMN			40
+#define DEFAULT_BRAILLE_MONITOR_USE_THEME		FALSE
+#define DEFAULT_BRAILLE_MONITOR_IS_PANEL		TRUE
+#define DEFAULT_BRAILLE_MONITOR_FONT_SIZE		18
+/*____________________________< /BRAILLE_MONITOR_DEFAULTS>___________________________*/
 /*____________________________< SRCORE_DEFAULTS>_____________________________*/
 #define DEFAULT_SRCORE_MAGNIF_ACTIVE		FALSE
 #define DEFAULT_SRCORE_SPEECH_ACTIVE		TRUE
@@ -94,13 +115,13 @@
 #define DEFAULT_SPEECH_COUNT_TYPE		"NONE"
 #define DEFAULT_SPEECH_VOICE_COUNT		0
 #define DEFAULT_SPEECH_CAPITAL			CAPITAL_IGNORE
-#define DEFAULT_SPEECH_PUNCTUATION		"SAME"
+#define DEFAULT_SPEECH_PUNCTUATION		"IGNORE"
 #define DEFAULT_SPEECH_TEXT_ECHO		"CHARACTER"
 #define DEFAULT_SPEECH_MODIFIERS		"NONE"
 #define DEFAULT_SPEECH_CURSORS			"NONE"
 #define DEFAULT_SPEECH_SPACES			"ALL"
 #define DEFAULT_SPEECH_ENGINE_VOICE		"V0 Adult Male 1 - IBM Viavoice GNOME Speech Driver"
-#define DEFAULT_SPEECH_ENGINE_DRIVER 		"IBM_Viavoice_GNOME_Speech_Driver"
+#define DEFAULT_SPEECH_ENGINE_DRIVER 		"IBM Viavoice GNOME Speech Driver"
 #define DEFAULT_SPEECH_DICTIONARY_ACTIVE	"NO"
 #define DEFAULT_SPEECH_DICTIONARY_ENTRY 	"USA<>United States Of America" 
 /*____________________________< /SPEECH_DEFAULTS>___________________________*/
@@ -180,9 +201,9 @@
 
 /*____________________________<BRAILLE>_______________________________________*/
 #define BRAILLE_ATTRIBUTES			"attribute"
-#define BRAILLE_STYLE 				"braille"
-#define BRAILLE_CURSOR				"cursor"
-#define BRAILLE_TRANSLATION 			"translation"
+#define BRAILLE_STYLE 				"braille_style"
+#define BRAILLE_CURSOR_STYLE			"cursor_style"
+#define BRAILLE_TRANSLATION 			"translation_table"
 #define BRAILLE_DEVICE 				"device"
 #define BRAILLE_PORT_NO 			"port_no"
 #define BRAILLE_FILL_CHAR 			"fill_char"
@@ -301,10 +322,25 @@
 /*____________________________<PRESENTATION>___________________________________*/
 #define PRESENTATION_CHANGES_END 		"/changes_end"
 /*____________________________</PRESENTATION>__________________________________*/
+/*____________________________</BRAILLE MONITOR>__________________________________*/
+#define BRAILLE_MONITOR_PANEL_POSITION_KEY 	"brlmon_position"
+#define BRAILLE_MONITOR_COLUMN_KEY	 	"cell_column"
+#define BRAILLE_MONITOR_LINE_KEY		"cell_line"
+#define BRAILLE_MONITOR_MODE_KEY		"display_mode"
+#define BRAILLE_MONITOR_DOT7_KEY 	 	"dot7"
+#define BRAILLE_MONITOR_DOT8_KEY 	 	"dot8"
+#define BRAILLE_MONITOR_DOT78_KEY 	 	"dot78"
+#define BRAILLE_MONITOR_USE_THEME_KEY		"use_theme_color"
+#define BRAILLE_MONITOR_IS_PANEL_KEY		"is_brlmon_panel"
+#define BRAILLE_MONITOR_FONT_SIZE_KEY		"font_size"
+/*____________________________</BRAILLE MONITOR>__________________________________*/
 /*____________________________<SECTIONS>__________________________________*/
 
 #define CONFIG_PATH 				"/apps/gnopernicus/"
 
+#define BRAILLE_MONITOR_PATH 			"brlmon"
+#define BRAILLE_MONITOR_KEY_PATH 		"brlmon/"
+
 #define BRAILLE_PATH 				"braille"
 #define BRAILLE_KEY_PATH			"braille/"
 
