@@ -36,9 +36,8 @@
 #include "srmain.h"
 #include "srpres.h"
 #include "srintl.h"
+#include "screen-review.h"
 
-#define MIN_BRAILLE_PORT 1
-#define MAX_BRAILLE_PORT 4
 
 static SRLClientHandle src_srl_client;
 gboolean src_use_braille = FALSE;
@@ -717,7 +716,6 @@ src_process_config_changed_for_srcore (SRConfigStructure *config)
 	    if (src_use_braille != *((gboolean*)config->newvalue))
 	    {
 		src_use_braille = *((gboolean*)config->newvalue);
-	    
 		if (src_use_braille)
 		{
 		    src_use_braille = src_braille_init ();
@@ -909,7 +907,7 @@ static gboolean src_crosswire	    	= FALSE;
 		{
 		    gchar *tmp;
 		    tmp = g_strdup_printf ("%s %s", 
-					   _("curent cursor is"), 
+					   _("current cursor is"), 
 					   cursors);
 		    src_say_message (tmp);
 		    g_free (tmp);
@@ -1056,8 +1054,8 @@ static gboolean src_crosswire	    	= FALSE;
 	    {
 		gchar *tmp;
 		tmp = g_strdup_printf (src_crosswire ? 
-				       _("crosswire on") :
-				       _("crosswire off"));
+				       _("crosshair on") :
+				       _("crosshair off"));
 		src_say_message (tmp);
 		g_free (tmp);
 	    }
@@ -1090,8 +1088,8 @@ static gboolean src_crosswire	    	= FALSE;
 	    {
 		gchar *tmp;
 		tmp = g_strdup_printf (crosswire_clip ? 
-				       _("crosswire clip on") :
-				       _("crosswire clipp off"));
+				       _("crosshair clip on") :
+				       _("crosshair clip off"));
 		src_say_message (tmp);
 		g_free (tmp);
 	    }
@@ -1130,7 +1128,7 @@ static gboolean src_crosswire	    	= FALSE;
 	    {
 		gchar *tmp;
 		tmp = g_strdup_printf ("%s %d", 
-				       _("crosswire size"), 
+				       _("crosshair size"), 
 				       crosswire_size);
 		src_say_message (tmp);
 		g_free (tmp);
@@ -1166,7 +1164,7 @@ static gboolean src_crosswire	    	= FALSE;
 	    {
 		gchar *tmp;
 		tmp = g_strdup_printf ("%s %u",
-				       _("crosswire color"),
+				       _("crosshair color"),
 				       crosswire_color);
 		src_say_message (tmp);
 		g_free (tmp);
@@ -2113,152 +2111,6 @@ src_translate_sensor_code (gchar *sensor_code,
     return rv;
 }
 
-SRLong src_text_index;
-
-static void
-src_position_sensor_action (gint index)
-{
-    if (!src_crt_sro)
-	return;
-	
-    src_text_index = index - 4 >= 0 ? index - 4 : 0;
-
-    switch (src_braille_position_sensor)
-    {
-	case 0:
-	    break;
-	case 1: 
-	    src_cmd_queue_add ("mouse goto current");
-	    src_cmd_queue_process ();
-	    break;
-	case 2:
-	    src_cmd_queue_add ("mouse goto current");
-	    src_cmd_queue_add ("mouse left click");
-	    src_cmd_queue_process ();
-	    break;
-	case 3:
-	    src_cmd_queue_add ("mouse goto current");
-	    src_cmd_queue_add ("mouse right click");
-	    src_cmd_queue_process ();
-	    break;
-	case 4:
-	    src_cmd_queue_add ("mouse goto current");
-/*
-	    src_cmd_queue_add ("mouse right click");
-	    src_cmd_queue_add ("mouse left click");
-*/
-	    src_cmd_queue_process ();
-	    break;
-	case 5:
-	    src_cmd_queue_add ("move caret");
-	    src_cmd_queue_process ();
-	    break;
-	case 6:
-	    src_cmd_queue_add ("show x coordinate");
-	    src_cmd_queue_process ();
-	    break;
-	case 7:
-	    src_cmd_queue_add ("show y coordinate");
-	    src_cmd_queue_process ();
-	    break;
-	case 8:
-	    src_cmd_queue_add ("font style");
-	    src_cmd_queue_process ();
-	    break;
-	case 9:
-	    src_cmd_queue_add ("font name");
-	    src_cmd_queue_process ();
-	    break;
-	case 10:
-	    src_cmd_queue_add ("font size");
-	    src_cmd_queue_process ();
-	    break;
-	case 11:
-	    sru_message ("sensor index 10 not implemented");
-	    break;
-	case 12:
-	    src_cmd_queue_add ("text attributes");
-	    src_cmd_queue_process ();
-	    break;
-	
-	default:
-	    sru_assert_not_reached ();
-	    break;
-    }	
-}
-
-static void
-src_optical_sensor_action (gint index)
-{
-    if (!src_crt_sro)
-	return;
-
-    src_text_index = index - 4 >= 0 ? index - 4 : 0;
-
-    switch (src_braille_optical_sensor)
-    {
-	case 0:
-	    break;
-	case 1: 
-	    src_cmd_queue_add ("mouse goto current");
-	    src_cmd_queue_process ();
-	    break;
-	case 2:
-	    src_cmd_queue_add ("mouse goto current");
-	    src_cmd_queue_add ("mouse left click");
-	    src_cmd_queue_process ();
-	    break;
-	case 3:
-	    src_cmd_queue_add ("mouse goto current");
-	    src_cmd_queue_add ("mouse right click");
-	    src_cmd_queue_process ();
-	    break;
-	case 4:
-	    src_cmd_queue_add ("mouse goto current");
-/*
-	    src_cmd_queue_add ("mouse right click");
-	    src_cmd_queue_add ("mouse left click");
-*/
-	    src_cmd_queue_process ();
-	    break;
-	case 5:
-	    src_cmd_queue_add ("move caret");
-	    src_cmd_queue_process ();
-	    break;
-	case 6:
-	    src_cmd_queue_add ("show x coordinate");
-	    src_cmd_queue_process ();
-	    break;
-	case 7:
-	    src_cmd_queue_add ("show y coordinate");
-	    src_cmd_queue_process ();
-	    break;
-	case 8:
-	    src_cmd_queue_add ("font style");
-	    src_cmd_queue_process ();
-	    break;
-	case 9:
-	    src_cmd_queue_add ("font name");
-	    src_cmd_queue_process ();
-	    break;
-	case 10:
-	    src_cmd_queue_add ("font size");
-	    src_cmd_queue_process ();
-	    break;
-	case 11:
-	    sru_message ("sensor index 10 not implemented");
-	    break;
-	case 12:
-	    src_cmd_queue_add ("text attributes");
-	    src_cmd_queue_process ();
-	    break;
-	default:
-	    sru_assert_not_reached ();
-	    break;
-    }	
-}
-
-
 static void
 src_process_braille_sensor (gchar *code)
 {
@@ -2273,10 +2125,10 @@ src_process_braille_sensor (gchar *code)
 	switch (type)
 	{
 	    case BST_PS:
-		src_position_sensor_action (index);
+		src_ctrl_position_sensor_action (index);
 		break;
 	    case BST_HOS:
-		src_optical_sensor_action (index);
+		src_ctrl_optical_sensor_action (index);
 		break;
 	    default:
 	    	fprintf (stderr, "SR: unsuported sensor code\n");
@@ -2297,7 +2149,8 @@ src_process_sro_event (SREvent *event,
     if (sre_get_event_data (event, (void**)&obj))
     {
 	src_process_sro (obj);
-	src_magnifier_start_panning (obj);
+	if (src_use_magnifier)
+	    src_magnifier_start_panning (obj);
     }
 /*
     {
@@ -2344,29 +2197,18 @@ src_process_mouse_event (SREvent *event,
 	
     if (sre_get_event_data (event, (void**)&point))
     {
-	static gboolean process = FALSE;
-	if (flags == 1) /* mouse:rel event */
-	{
-	    process = TRUE;
-	    src_magnifier_stop_panning ();
-	}
-	else if (process)
-	{
-	    gchar *magout;
-	    magout = g_strdup_printf ("<MAGOUT><ZOOMER ID =\"%s\" tracking=\"mouse\" ROILeft =\"%d\" ROITop =\"%d\" ROIWidth =\"%d\" ROIHeight=\"%d\"></ZOOMER></MAGOUT>",
+	gchar *magout;
 
+	src_magnifier_stop_panning ();
+	magout = g_strdup_printf ("<MAGOUT><ZOOMER ID =\"%s\" tracking=\"mouse\" ROILeft =\"%d\" ROITop =\"%d\" ROIWidth =\"%d\" ROIHeight=\"%d\"></ZOOMER></MAGOUT>",
 				"generic_zoomer",
 				point->x, point->y, point->x + 1, point->y + 1);
-	    if (magout)
-	    	src_magnifier_send (magout);
-	    g_free (magout);
-	    process = FALSE;
-	}
+	if (magout)
+	    src_magnifier_send (magout);
+	g_free (magout);
     }
 }
 
-
-
 static void
 src_event_sink(SREvent *event_, 
 	       unsigned long flags)
@@ -2415,6 +2257,15 @@ src_event_sink(SREvent *event_,
 		    break;		 
 	    }
 */	
+	    switch (type)
+	    {
+		case SR_EVENT_SRO:
+		case SR_EVENT_WINDOW:
+		    src_ctrl_flat_mode_terminate ();
+		    break;
+		default:
+		    break;
+	    }
 	    switch (type)
 	    {
 		case SR_EVENT_CONFIG_CHANGED:
@@ -2451,15 +2302,6 @@ src_event_sink(SREvent *event_,
 		    sru_assert_not_reached ();
 		    break;
 	    }
-	    switch (type)
-	    {
-		case SR_EVENT_SRO:
-		case SR_EVENT_WINDOW:
-		    src_ctrl_flat_mode_terminate ();
-		    break;
-		default:
-		    break;
-	    }
 	}
 	sre_release_reference (event);
     }
@@ -2502,7 +2344,9 @@ src_get_defaults ()
     /* get braille port*/
 /*
     if (MIN_BRAILLE_PORT <= src_braille_port && src_braille_port <= MAX_BRAILLE_PORT)
+    {
 	SET_BRAILLE_CONFIG_DATA (BRAILLE_PORT_NO, CFGT_INT, &src_braille_port);
+    }
     else
     {
 	gint default_port = DEFAULT_BRAILLE_PORT_NO;
@@ -2513,7 +2357,9 @@ src_get_defaults ()
     /* get braille device*/
 /*
     if (src_braille_device)
+    {
 	SET_BRAILLE_CONFIG_DATA (BRAILLE_DEVICE, CFGT_STRING, &src_braille_device);
+    }
     else
     {
 	gchar *default_device = DEFAULT_BRAILLE_DEVICE;
@@ -2553,16 +2399,30 @@ src_get_defaults ()
 		    CFGT_INT, &src_braille_optical_sensor, &default_sensor);
     }
     
-
-    GET_SRCORE_CONFIG_DATA_WITH_DEFAULT (SRCORE_BRAILLE_ACTIVE, CFGT_BOOL, 
+    if (!src_use_braille)
+    {
+	GET_SRCORE_CONFIG_DATA_WITH_DEFAULT (SRCORE_BRAILLE_ACTIVE, CFGT_BOOL, 
 	    &src_use_braille, &src_use_braille);
-    GET_SRCORE_CONFIG_DATA_WITH_DEFAULT (SRCORE_BRAILLE_MONITOR_ACTIVE, CFGT_BOOL, 
+    }
+    
+    if (!src_use_braille_monitor)
+    {
+	GET_SRCORE_CONFIG_DATA_WITH_DEFAULT (SRCORE_BRAILLE_MONITOR_ACTIVE, CFGT_BOOL, 
 	    &src_use_braille_monitor, &src_use_braille_monitor);
-    GET_SRCORE_CONFIG_DATA_WITH_DEFAULT (SRCORE_SPEECH_ACTIVE, CFGT_BOOL, 
-	    &src_use_speech, &src_use_speech);
-    GET_SRCORE_CONFIG_DATA_WITH_DEFAULT (SRCORE_MAGNIF_ACTIVE, CFGT_BOOL, 
-	    &src_use_magnifier, &src_use_magnifier);
+    }
+    
+    if (!src_use_speech)
+    {
+	GET_SRCORE_CONFIG_DATA_WITH_DEFAULT (SRCORE_SPEECH_ACTIVE, CFGT_BOOL, 
+					    &src_use_speech, &src_use_speech);
+    }
 
+    if (!src_use_magnifier)
+    {
+	GET_SRCORE_CONFIG_DATA_WITH_DEFAULT (SRCORE_MAGNIF_ACTIVE, CFGT_BOOL, 
+					    &src_use_magnifier, &src_use_magnifier);
+    }
+    
     GET_SRCORE_CONFIG_DATA_WITH_DEFAULT (KEYBOARD_TAKE_MOUSE, CFGT_BOOL, 
 	    &src_mouse_take, &src_mouse_take);
     GET_SRCORE_CONFIG_DATA_WITH_DEFAULT (KEYBOARD_SIMULATE_CLICK, CFGT_BOOL, 
@@ -2570,9 +2430,10 @@ src_get_defaults ()
 	    
 }
 
-gchar *src_message;
+static gchar *src_message;
+
 gboolean 
-src_say_message (gchar *message)
+src_say_message (const gchar *message)
 {
     if (src_message)
 	g_free (src_message);
@@ -2614,7 +2475,6 @@ src_init()
     src_ctrl_init ();
     
 /*    src_speech_count_mode = DEFAULT_SPEECH_REPEAT_TYPE;*/
-
     src_get_defaults ();
 
     /* initialize Braille */
@@ -2624,7 +2484,6 @@ src_init()
 	if (!src_use_braille)
 	    brl_error = TRUE;
     }
-	
     if (src_use_braille_monitor)
 	src_use_braille_monitor = src_braille_monitor_init ();
  	
@@ -2682,7 +2541,7 @@ static void
 src_terminate()
 {
     gboolean exitack = TRUE;
-    gchar *message = _("now gnopernicus will gonna exit");
+    gchar *message = _("Gnopernicus is now exiting. Have a nice day!");
 
     if (src_focused_sro)
 	sro_release_reference (src_focused_sro);
@@ -2701,6 +2560,11 @@ src_terminate()
 	
     if (src_use_speech)
 	src_say_message (message);
+    /* FIXME remus: maybe this function should not be called here, in respect to
+    current design */
+    /* terminate screen review in case that Exit was called and gnopernicus
+    is still in flat review mode*/
+    screen_review_terminate ();
 	
     /* terminate SRLow */
     srl_remove_client (src_srl_client);
@@ -2709,6 +2573,10 @@ src_terminate()
     /* terminate Keyboard */
     ke_terminate();
 
+    /* terminate Magnifier */
+    if (src_use_magnifier)
+	src_magnifier_terminate (); 
+
     /* terminate Braille */
     if (src_use_braille)
 	src_braille_terminate ();
@@ -2717,10 +2585,6 @@ src_terminate()
     if (src_use_braille_monitor)
 	src_brlmon_terminate ();
 
-    /* terminate Magnifier */
-    if (src_use_magnifier)
-	src_magnifier_terminate (); 
-
     /* terminate Speech */
     if (src_use_speech)
 	src_speech_terminate ();
@@ -2756,14 +2620,23 @@ gint
 main (gint argc, 
       gchar **argv)
 {
-    gchar *device = NULL;
+    gboolean braille 		= FALSE;
+    gboolean speech 		= FALSE;
+    gboolean magnifier 		= FALSE;
+    gboolean braille_monitor 	= FALSE;
+    
 
     struct poptOption poptopt[] = 
     {		
-	{"device", 	'd', POPT_ARG_STRING, 	&device,  	'd', "Braille Device", 		"device_name"},
-	{"port", 	'p', POPT_ARG_INT, 	&src_braille_port,'p', "Serial port (ttyS)", 	"serial_port_no"},
+	{"braille",	  'b', 	POPT_ARG_NONE,  &braille,	'b', "Launch in execution with braille", NULL},
+	{"speech",	  's', 	POPT_ARG_NONE,  &speech,	's', "Launch in execution with speech", NULL},
+	{"magnifier",	  'm', 	POPT_ARG_NONE,  &magnifier,	'm', "Launch in execution with magnifier",  NULL},
+	{"braille-monitor", 'r', POPT_ARG_NONE, &braille_monitor, 'r', "Launch in execution with braille monitor", NULL},
+	{"braille-device",'e',  POPT_ARG_STRING, &src_braille_device,  'e', "Braille Device", 		"device_name"},
+	{"braille-port",  'p',  POPT_ARG_INT, 	&src_braille_port,'p', "Serial port (ttyS)", 	"serial_port_no"},
 	{NULL, 		0,0, NULL, 0}
     };
+    
 #ifdef ENABLE_NLS
     bindtextdomain (GETTEXT_PACKAGE, GNOPERNICUSLOCALEDIR);
     textdomain (GETTEXT_PACKAGE);
@@ -2775,8 +2648,7 @@ main (gint argc,
     fprintf (stderr, "\n**********************");
     fprintf (stderr, "\n* SCREEN READER CORE *");
     fprintf (stderr, "\n**********************\n\n");
-    
-    src_braille_device = NULL;
+        
     gnome_program_init ("srcore", VERSION,
 		    LIBGNOMEUI_MODULE,
 		    argc, argv,
@@ -2785,18 +2657,17 @@ main (gint argc,
 		    LIBGNOMEUI_PARAM_CRASH_DIALOG, FALSE,
 		    NULL);
     sru_log_init ();
-	
-    if (device)
-	{
-	    if (src_braille_device) 
-		g_free (src_braille_device);
-	    src_braille_device = g_strdup (device);
-	    g_free (device);
-	}
-    if (src_braille_port <= MIN_BRAILLE_PORT && src_braille_port >= MAX_BRAILLE_PORT)
-	{
-	    src_braille_port = DEFAULT_BRAILLE_PORT_NO;
-	}
+
+    if (src_braille_port <= MIN_BRAILLE_PORT && 
+	src_braille_port >= MAX_BRAILLE_PORT)
+    {
+	src_braille_port = DEFAULT_BRAILLE_PORT_NO;
+    }
+
+    src_use_braille 		= braille;
+    src_use_speech 		= speech;
+    src_use_magnifier 		= magnifier;
+    src_use_braille_monitor 	= braille_monitor;
 
     src_init ();
 
@@ -2805,6 +2676,7 @@ main (gint argc,
     src_terminate ();
     
     sru_log_terminate ();
+    
     return EXIT_SUCCESS;
 }
 
